// MRFC522 Card Access Checker V2.1a
// Reads and checks card UID before activating relay and sounder

// Include the library routines
#include <SPI.h>
#include <MFRC522.h>

// Define the pins
#define RST_PIN 9
#define SS_PIN  10
#define sounder 7
#define relay 6

// Create an instance of the MFRC522
MFRC522 mfrc522(SS_PIN, RST_PIN);

// Set-up code
void setup() {
  Serial.begin(9600);    // Initialize serial port communication
  SPI.begin();      // Initialise the SPI bus
  mfrc522.PCD_Init();   // Initialise the MFRC522
  digitalWrite(relay, LOW);      // Relay non-energized
  digitalWrite(sounder, LOW);    // No sound
  Serial.println("Card Access Checker V1.1a");
  Serial.println("Pleace your card or tag close to the reader ...");
}

void loop() {
  byte i;

  // Is a card detected?
  if (mfrc522.PICC_IsNewCardPresent())
  {

    // Can the serial number be read?
    if (mfrc522.PICC_ReadCardSerial())
    {

      // We have a card and its serial number so we can now format and verify the UID

      String content = "";
      for (byte i = 0; i < mfrc522.uid.size; i++)
      {
        content.concat(String(mfrc522.uid.uidByte[i] < 0x10 ? " 0" : " "));
        content.concat(String(mfrc522.uid.uidByte[i], HEX));
      }
      Serial.println();
      Serial.print("Card detected : ");

      content.toUpperCase();
      if (content.substring(1) == "83 1D 3F 03") // Change this UID to suit the card
      {
        Serial.println("Access granted");
        Serial.println();
        // Beep door opening
        digitalWrite(sounder, HIGH);
        delay(500);
        digitalWrite(sounder, LOW);
        // Activate door relay
        digitalWrite(relay, HIGH);    // Relay energized
        delay(2500);
        digitalWrite(relay, LOW);     // Relay non-energized
      }

      else   {
        Serial.println("Access denied");
        Serial.println();
        delay(2500);
      }
    }
  }
}
